/* Slovenian localization for the jQuery time picker plugin. */
/* Written by  Blaž Maležič (blaz@malezic.si)              */
jQuery(function($){
    $.timepicker.regional['sl'] = {
                hourText: 'Ure',
                minuteText: 'Minute',
                amPmText: ['AM', 'PM'],
                closeButtonText: 'Zapri',
                nowButtonText: 'Zdaj',
                deselectButtonText: 'Pobriši' }
    $.timepicker.setDefaults($.timepicker.regional['sl']);
});
