{% load i18n %}

{% if module.error %}
    <ul>
        <li>
            {{ module.error }}
        </li>
    </ul>
{% elif module.children %}
    <div class="padding center">
        <ul class="inline bordered">
            {% for statistic in module.children %}
                <li>
                    <div class="big">{{ statistic.value }}</div>
                    <div class="dim">{{ statistic.title }}</div>
                </li>
            {% endfor %}
        </ul>
    </div>
{% else %}
    <ul>
        <li>
            {% trans "Nothing to show" %}
        </li>
    </ul>
{% endif %}
