{% load i18n %}

<ul>
    {% if module.children %}
        {% for child in module.children %}
            <li>
                {% if child.date %}<span class="float-right dim">{{ child.date|date }}</span>{% endif %}
                {% if child.warning %}<span class="warning">{{ child.title }}</span>{% else %}<a href="{{ child.link }}" target="_blank" class="nowrap"><span class="fas fa-external-link-alt"></span> {{ child.title }}</a>{% endif %}
            </li>
        {% endfor %}
    {% else %}
        <li>
            {% trans "Nothing to show" %}
        </li>
    {% endif %}
</ul>
