{% load i18n jet_tags %}

{% if wrap != False %}<fieldset class="module aligned">{% endif %}
    {% for field in form %}
        {% if field.name != 'DELETE' %}
            <div class="form-row{% if field.errors %} errors{% endif %}">
                {{ field.errors }}

                {% if field|jet_is_checkbox %}
                    {{ field }} <label{% if field.field.required %} class="required"{% endif %} for="{{ field.id_for_label }}">{{ field.label }}</label>
                {% else %}
                    <label{% if field.field.required %} class="required"{% endif %} for="{{ field.id_for_label }}">{{ field.label }}:</label>
                    {{ field }}
                {% endif %}

                {% if field.field.help_text %}
                    <p class="help">{{ field.field.help_text|safe }}</p>
                {% endif %}
            </div>
        {% endif %}
    {% endfor %}
{% if wrap != False %}</fieldset>{% endif %}
